// Copyright (C) 2022 - 2023, Xilinx Inc - All rights reserved
//
// Licensed under the Apache License, Version 2.0 (the "License"). You may
// not use this file except in compliance with the License. A copy of the
// License is located at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
// WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
// License for the specific language governing permissions and limitations
// under the License.

#pragma once

#include "xma.h"
#include <memory>

namespace xma {

class Log {
protected:
  Log() = default;

public:
  virtual ~Log() = default;
  static std::shared_ptr<Log> MakeLog(XmaLogLevelType log_level, XmaLogType log_type, ...);
  static std::shared_ptr<Log> MakeLogList(XmaLogLevelType log_level, XmaLogType log_type, va_list arg);

  void         LogMsg(XmaLogLevelType level, const char* name, const char* msg, ...);
  virtual void LogMsgList(XmaLogLevelType level, const char* name, const char* msg, va_list arg) = 0;

  virtual XmaLogLevelType GetLogLevel() const = 0;
  virtual XmaLogType      GetLogType() const  = 0;
};

using LogPtr = std::shared_ptr<Log>;

} // namespace xma
