// Copyright (C) 2022 - 2023, Xilinx Inc - All rights reserved
//
// Licensed under the Apache License, Version 2.0 (the "License"). You may
// not use this file except in compliance with the License. A copy of the
// License is located at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
// WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
// License for the specific language governing permissions and limitations
// under the License.

#pragma once

#include <string.h>

#include <xma.h>

#include "xlnx_app_utils.h"
#include "xlnx_ml_common.h"

typedef struct XlnxMLProps {
    uint32_t device_id;
    int32_t  log_level;

    uint32_t num_inputs;
    uint32_t num_outputs;

    XmaFormatType input_pix_fmt;
    int32_t       input_width;
    int32_t       input_height;
    int32_t       input_fps_num;
    int32_t       input_fps_den;

    char* model_name;
    char* model_arg;
    char* ml_perf;
    char* ml_tensor_dump;
    char* ml_inf_repeat;

    int32_t input_stride;
} XlnxMLProps;

/**
 * xlnx_ml_cleanup_props: Free resources allocated in the ml
 * props.
 *
 * @param ml_xma_props: The xma ml properties
 */
void xlnx_ml_cleanup_props(XmaMioFilterProperties* ml_xma_props);

/**
 * xlnx_ml_create_xma_props: Create the xma ml properties
 * given the param ctx and session id.
 *
 * @param handle: The xma handle shared between xma sessions.
 * @param param_ctx: The parameter context containing ml param
 *                 values
 * @param ml_xma_props: The ml xma properties which will be
 *                   filled
 * @return XMA_APP_SUCCESS on success
 */
int32_t xlnx_ml_create_xma_props(XmaHandle handle, XlnxMLProps* param_ctx,
                                 XmaFilterProperties*    xma_upload_props,
                                 XmaFilterProperties*    xma_download_props,
                                 XmaMioFilterProperties* ml_xma_props);
